pub struct DirEntry { /* private fields */ }fs_utf8 only.Expand description
Entries returned by the ReadDir iterator.
This corresponds to std::fs::DirEntry.
Unlike std::fs::DirEntry, this API has no DirEntry::path, because
absolute paths don’t interoperate well with the capability model.
There is a file_name function, however there are also open,
open_with, open_dir, remove_file, and remove_dir functions for
opening or removing the entry directly, which can be more efficient and
convenient.
Note that there is no from_std method, as std::fs::DirEntry doesn’t
provide a way to construct a DirEntry without opening directories by
ambient paths.
Implementations
Constructs a new instance of Self from the given
cap_std::fs::DirEntry.
Open the file with the given options.
Removes the file from its filesystem.
Removes the directory from its filesystem.
Returns the metadata for the file that this entry points at.
This corresponds to std::fs::DirEntry::metadata.
Returns the file type for the file that this entry points at.
This corresponds to std::fs::DirEntry::file_type.
Returns the bare file name of this directory entry without any other leading path component.
This function returns an Err in the case that the file name isn’t
encodable as UTF-8.
If the arf_strings feature is enabled, unencodable names are
translated to UTF-8 using arf-strings.
This corresponds to std::fs::DirEntry::file_name.